import subprocess

from srai_core.command_handler_base import CommandHandlerBase


class CommandHandlerSubprocess(CommandHandlerBase):
    def __init__(self) -> None:
        pass

    def execute(self, command: str) -> None:
        # Execute the command
        print(command)
        subprocess.run(command, shell=True)

    def to_dict(self) -> dict:
        return {"__Type__": "CommandHandlerSubprocess"}

    @staticmethod
    def from_dict(dict_command_handler: dict) -> CommandHandlerBase:
        return CommandHandlerSubprocess()



import os
from typing import Dict

from srai_core.store.bytes_store_base import BytesStoreBase


class BytesStoreDisk(BytesStoreBase):
    # file store for

    def __init__(self, path_dir: str) -> None:
        self.path_dir = path_dir
        if not os.path.exists(self.path_dir):
            os.makedirs(self.path_dir)

    def get_path_file(self, bytes_id: str) -> str:
        return os.path.join(self.path_dir, bytes_id)

    def exists_bytes(self, bytes_id: str) -> bool:
        return os.path.isfile(self.get_path_file(bytes_id))

    def count_bytes(self) -> int:
        return len([name for name in os.listdir(self.path_dir) if name.endswith(".json")])

    def load_bytes(self, bytes_id: str) -> bytes:
        if not self.exists_bytes(bytes_id):
            raise ValueError(f"Document not found: {bytes_id}")
        with open(self.get_path_file(bytes_id), "rb") as file:
            return file.read()

    def load_bytes_all(self) -> Dict[str, bytes]:
        dict_document = {}
        for file in os.listdir(self.path_dir):
            bytes_id = file.split(".")[0]
            with open(os.path.join(self.path_dir, file), "rb") as file:
                dict_document[bytes_id] = file.read()
        return dict_document

    def delete_bytes(self, bytes_id: str) -> None:
        os.remove(self.get_path_file(bytes_id))

    def delete_bytes_all(self) -> int:
        count = self.count_bytes()
        for file in os.listdir(self.path_dir):
            os.remove(os.path.join(self.path_dir, file))
        return count

    def save_bytes(self, bytes_id: str, bytes: bytes) -> None:
        with open(self.get_path_file(bytes_id), "wb") as file:
            file.write(bytes)



import hashlib
import json

from srai_core.file_store import FileStore


class JsondictStore:
    # file store for

    def __init__(self, backing_store: FileStore) -> None:
        self.backing_store = backing_store

    def sha256hexdigest(self, jsondict_key: dict) -> str:
        # convert a jsondict_key to a sha256 hash digest
        # jsondict_key is a dict of key value pairs
        jsondict_key_bytes = json.dumps(jsondict_key).encode("utf-8")
        return hashlib.sha256(jsondict_key_bytes).hexdigest()

    def exists(self, jsondict_key: dict) -> bool:
        key = self.sha256hexdigest(jsondict_key)
        return self.backing_store.exists(key)

    def read_jsondict(self, jsondict_key: dict) -> bool:
        key = self.sha256hexdigest(jsondict_key)
        self.backing_store.download(key)
        path_file = self.backing_store.get_path_file(key)
        with open(path_file, "r") as file:
            return json.load(file)

    def write_jsondict(self, jsondict_key: dict, jsondict_value: dict) -> None:
        key = self.sha256hexdigest(jsondict_key)
        path_file = self.backing_store.get_path_file(key)
        with open(path_file, "w") as file:
            json.dump(jsondict_value, file)
        self.backing_store.upload(key)



from abc import ABC, abstractmethod
from typing import Dict


class DocumentStoreBase(ABC):
    # file store for

    def __init__(self) -> None:
        pass

    @abstractmethod
    def exists_document(self, document_id: str) -> bool:
        raise NotImplementedError()

    @abstractmethod
    def count_document(self) -> int:
        raise NotImplementedError()

    @abstractmethod
    def load_document(self, document_id: str) -> dict:
        raise NotImplementedError()

    @abstractmethod
    def load_document_all(self) -> Dict[str, dict]:
        raise NotImplementedError()

    def load_document_for_query(self, query: Dict[str, str]) -> Dict[str, dict]:
        dict_document = self.load_document_all()
        dict_selected = {}
        for document_id, document in dict_document.items():
            for key in query:
                if key not in document:
                    continue
                if document[key] == query[key]:
                    dict_selected[document_id] = document
        return dict_selected

    @abstractmethod
    def delete_document(self, document_id: str) -> None:
        raise NotImplementedError()

    @abstractmethod
    def save_document(self, document_id: str, document: dict) -> None:
        raise NotImplementedError()



from srai_core.tools_docker import (
    build_docker,
    start_container,
    get_image_tag,
    stop_container,
    remove_container,
)
import os
import sys
from srai_core.command_handler_subprocess import CommandHandlerSubprocess
import json


def main():
    if len(sys.argv) < 2:
        print("Usage: deploy_docker deployment_file.json")
        sys.exit(1)

    path_deployment_file = sys.argv[1]
    with open(path_deployment_file) as f:
        deployment = json.load(f)
    deployment_type = deployment["deployment_target"]["deployment_type"]
    if deployment_type == "localhost":
        command_handler = CommandHandlerSubprocess()
    elif deployment_type == "ssh":
        command_handler = CommandHandlerSubprocess()
    else:
        print(f"Unknown deployment type: {deployment_type}")
        sys.exit(1)

    build_docker(command_handler)
    image_tag = get_image_tag()
    dict_env = deployment["environment_dict"]

    dict_env["IMAGE_TAG"] = image_tag

    container_name = image_tag.split(":")[0].split("/")[-1]

    stop_container(command_handler, container_name)
    remove_container(command_handler, container_name)
    start_container(command_handler, image_tag, container_name, dict_env)


if __name__ == "__main__":
    main()



import asyncio
import json
import sys

from srai_core.command_handler_base import CommandHandlerBase
from srai_core.tools_docker import build_docker_async


async def srai_build() -> None:
    if len(sys.argv) < 2:
        print("Usage: deploy_docker deployment_file.json")
        sys.exit(1)

    path_deployment_file = sys.argv[1]
    with open(path_deployment_file) as f:
        deployment = json.load(f)

    for build_target in deployment["list_build_target"]:
        await build_docker_async(CommandHandlerBase.from_dict(build_target))


def main():
    asyncio.run(srai_build())


if __name__ == "__main__":
    main()



import json
import os
from typing import Dict

from srai_core.store.document_store_base import DocumentStoreBase


class DocumentStoreDisk(DocumentStoreBase):
    # file store for

    def __init__(self, path_dir: str) -> None:
        self.path_dir = path_dir
        if not os.path.exists(self.path_dir):
            os.makedirs(self.path_dir)

    def get_path_file(self, document_id: str) -> str:
        return os.path.join(self.path_dir, document_id + ".json")

    def exists_document(self, document_id: str) -> bool:
        return os.path.isfile(self.get_path_file(document_id))

    def count_document(self) -> int:
        return len([name for name in os.listdir(self.path_dir) if name.endswith(".json")])

    def load_document(self, document_id: str) -> dict:
        if not self.exists_document(document_id):
            raise ValueError(f"Document not found: {document_id}")
        with open(self.get_path_file(document_id), "r") as file:
            return json.load(file)

    def load_document_all(self) -> Dict[str, dict]:
        dict_document = {}
        for file in os.listdir(self.path_dir):
            if file.endswith(".json"):
                document_id = file.split(".")[0]
                with open(os.path.join(self.path_dir, file), "r") as file:
                    dict_document[document_id] = json.load(file)
            else:
                raise Exception(f"File {file} is not a json file")
        return dict_document

    def delete_document(self, document_id: str) -> None:
        os.remove(self.get_path_file(document_id))

    def delete_document_all(self) -> int:
        count = self.count_document()
        for file in os.listdir(self.path_dir):
            if file.endswith(".json"):
                os.remove(os.path.join(self.path_dir, file))
            else:
                raise Exception(f"File {file} is not a json file")
        return count

    def save_document(self, document_id: str, document: dict) -> None:
        with open(self.get_path_file(document_id), "w") as file:
            json.dump(document, file)
